@@ -1,5 +1,7 @@
-import ast
+import json
+import six
 
+from rest_framework import exceptions
 from rest_framework.serializers import *
 
 # Haking rest_framework in order to meet our crazy design specifications
@@ -17,7 +19,11 @@ class RelHyperlinkedRelatedField(HyperlinkedRelatedField):
         return {'uri': url}
     
     def from_native(self, value):
-        value = ast.literal_eval(str(value)).pop('uri')
+        # TODO this is bullshit, fixit!
+        if isinstance(value, six.text_type):
+            value = value.replace("u'", '"').replace("'", '"')
+            value = json.loads(value)
+        value = value.pop('uri')
         return super(RelHyperlinkedRelatedField, self).from_native(value)
 
 
@@ -58,12 +64,16 @@ class PropertyField(WritableField):
         properties = []
         if value:
             model = getattr(parent.opts.model, self.source or 'properties').related.model
-            dict_value = ast.literal_eval(str(value))
+            if isinstance(value, six.text_type):
+                try:
+                    value = json.loads(value)
+                except:
+                    raise exceptions.ParseError("Malformed property: %s" % str(value))
             if not related_manager:
                 # POST (new parent object)
-                return [ model(name=n, value=v) for n,v in dict_value.iteritems() ]
+                return [ model(name=n, value=v) for n,v in value.iteritems() ]
             # PUT
-            for (name, value) in dict_value.iteritems():
+            for (name, value) in value.iteritems():
                 try:
                     # Update existing property
                     prop = related_manager.get(name=name)
@@ -73,6 +83,7 @@ class PropertyField(WritableField):
                 else:
                     prop.value = value
                 properties.append(prop)
+        # TODO this should be done on save()
         # Discart old values
         if related_manager:
             related_manager.all().delete()
