@@ -107,9 +107,7 @@ class Build(models.Model):
     def task(self):
         return build_task.AsyncResult(self.task_id)
     
-    @property
-    def state(self):
-        """ Gives the current state of the build """
+    def _compute_state(self):
         if self.image:
             try:
                 self.image.file
@@ -129,6 +127,14 @@ class Build(models.Model):
             return self.BUILDING
         return self.FAILED
     
+    @property
+    def state(self):
+        """ Gives the current state of the build """
+        if hasattr(self, '_cached_state'):
+            return self._cached_state
+        self._cached_state = self._compute_state()
+        return self._cached_state
+    
     @property
     def state_description(self):
         description = {
@@ -179,6 +185,8 @@ class Build(models.Model):
     
     def match(self, config):
         """ Checks if a a given build is up-to-date or not """
+        # TODO including non-atomic content (like cryptographyc keys) files
+        #      will result in False matching
         if self.version != config.version:
             return False
         base_images = [ image.image for image in config.get_images(self.node) ]
@@ -186,7 +194,7 @@ class Build(models.Model):
             return False
         config = Config.objects.get()
         exclude = config.files.optional().values_list('pk', flat=True)
-        old_files = self.files.exclude(config__pk__in=exclude)
+        old_files = self.files.exclude(config__is_optional=True)
         old_files = set( (f.path,f.content) for f in old_files )
         new_files = config.eval_files(self.node, exclude=exclude)
         new_files = set( (f.path,f.content) for f in new_files )
