@@ -1,5 +1,4 @@
 from django import forms
-from django.core.urlresolvers import reverse
 from django.utils.html import strip_tags
 from django.utils.safestring import mark_safe
 from markdown import markdown
@@ -8,7 +7,7 @@ from controller.forms.utils import admin_link
 from controller.forms.widgets import ReadOnlyWidget, ShowText
 from users.models import User
 
-from issues.models import Queue, Ticket
+from .models import Queue, Ticket
 
 
 markdown_url = '/static/issues/markdown_syntax.html'
@@ -58,7 +57,7 @@ class UsersIterator(forms.models.ModelChoiceIterator):
 
     def __iter__(self):
         yield ('', '---------')
-        users = User.objects.all()
+        users = User.objects.all().order_by('username')
         superusers = users.filter(is_superuser=True)
         if superusers:
             yield ('Operators', list(superusers.values_list('pk', 'username')))
