@@ -112,17 +112,20 @@ class Ticket(models.Model):
         emails.append(self.created_by.email)
         if self.owner:
             emails.append(self.owner.email)
-        if self.group:
-            roles = [Roles.ADMIN]
-            if self.queue:
-                roles = []
-                if self.queue.notify_admins:
-                    roles.append(Roles.ADMIN)
-                if self.queue.notify_technicians:
-                    roles.append(Roles.TECHNICIAN)
-                if self.queue.notify_researchers:
-                    roles.append(Roles.RESEARCHER)
-            emails += self.group.get_emails(roles=roles)
+        elif self.queue:
+            roles = []
+            if self.queue.notify_admins:
+                roles.append(Roles.ADMIN)
+            if self.queue.notify_technicians:
+                roles.append(Roles.TECHNICIAN)
+            if self.queue.notify_researchers:
+                roles.append(Roles.RESEARCHER)
+            if self.group and roles:
+                emails += self.group.get_emails(roles=roles)
+            elif roles:
+                emails += User.get_emails(roles=roles)
+        elif self.group:
+            emails += self.group.get_emails(role=Roles.ADMIN)
         for message in self.messages.distinct('author'):
             author = message.author
             if self.is_visible_by(author):
