@@ -33,7 +33,7 @@ STATES_COLORS = {
 
 class NodePropInline(PermissionTabularInline):
     model = NodeProp
-    extra = 0
+    extra = 1
     verbose_name_plural = mark_safe('Node properties %s' % docstring_as_help_tip(NodeProp))
     
     class Media:
@@ -50,7 +50,7 @@ class NodeAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdmin
         'name', 'id', 'arch', 'display_set_state', admin_link('group'), 'num_ifaces'
     ]
     list_display_links = ['name', 'id']
-    list_filter = [MyNodesListFilter, 'arch', 'set_state']
+    list_filter = [MyNodesListFilter, 'arch', 'set_state', 'group']
     default_changelist_filters = (('my_nodes', 'True'),)
     search_fields = ['description', 'name', 'id']
     readonly_fields = ['boot_sn', 'display_cert']
@@ -168,6 +168,9 @@ class NodeAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdmin
             obj = self.get_object(request, object_id)
             if obj and not obj.cert:
                 messages.warning(request, 'This node lacks a valid certificate.')
+            if obj and not obj.group.allow_nodes:
+                msg = "The node group does not have permissions to manage nodes"
+                messages.warning(request, msg)
         return super(NodeAdmin, self).change_view(request, object_id,
                 form_url=form_url, extra_context=extra_context)
 
