@@ -9,7 +9,7 @@ from django.db import models
 from controller.utils.apps import is_installed
 from controller.utils.time import heartbeat_expires
 
-from .settings import PING_INSTANCES
+from .settings import PING_DEFAULT_INSTANCE, PING_INSTANCES, PING_COUNT
 
 
 for instance in PING_INSTANCES:
@@ -29,16 +29,18 @@ class Ping(models.Model):
     
     content_type = models.ForeignKey(ContentType)
     object_id = models.PositiveIntegerField()
+    samples = models.PositiveIntegerField(default=PING_COUNT)
     packet_loss = models.PositiveIntegerField(null=True)
     min = models.DecimalField('RTT min', decimal_places=3, max_digits=9, null=True)
     avg = models.DecimalField('RTT avg', decimal_places=3, max_digits=9, null=True)
     max = models.DecimalField('RTT max', decimal_places=3, max_digits=9, null=True)
     mdev = models.DecimalField('RTT mdev', decimal_places=3, max_digits=9, null=True)
-    date = models.DateTimeField(auto_now_add=True, null=True, db_index=True)
+    date = models.DateTimeField()
     
     content_object = generic.GenericForeignKey()
     
     class Meta:
+        index_together = [['object_id', 'content_type', 'date']]
         ordering = ('-date',)
     
     @classmethod
@@ -62,7 +64,9 @@ class Ping(models.Model):
         if not (isinstance(model, unicode) or isinstance(model, str)):
             model = "%s.%s" % (model._meta.app_label, model._meta.object_name)
         for instance in PING_INSTANCES:
-            if model == instance.get('model'):
+            settings = PING_DEFAULT_INSTANCE.copy()
+            settings.update(instance)
+            if model == settings.get('model'):
                 if setting:
-                    return instance.get(setting)
-                return instance
+                    return settings.get(setting)
+                return settings
