@@ -1,5 +1,7 @@
 import decimal
+import math
 import subprocess
+import sys
 import os
 from datetime import datetime
 
@@ -11,6 +13,7 @@ from django.utils import timezone
 
 from controller.utils import LockFile
 from controller.utils.apps import is_installed
+from controller.utils.time import group_by_interval, get_sloted_start
 
 from .models import Ping
 from .settings import PING_LOCK_DIR, PING_COUNT, PING_INSTANCES
@@ -37,7 +40,7 @@ def pinger(ip):
     if ping.returncode == 0:
         stdout = ping.stdout.readlines()
         ping.stdout.close()
-        packet_loss = decimal.Decimal(stdout[-2].split(',')[2].split('%')[0])
+        packet_loss = decimal.Decimal(stdout[-2].split(', ')[-2].split('%')[0])
         perf_type = ['min', 'avg', 'max', 'mdev']
         perf_data = stdout[-1].split(' ')[3].split('/')
         result = dict((k, decimal.Decimal(v)) for k,v in zip(perf_type, perf_data))
@@ -79,84 +82,80 @@ def ping(model, ids=[], lock=True):
             coroutine = pinger(get_addr(obj))
             coroutine.next()
             pool.append(coroutine)
+        now = timezone.now()
         # Get the results
         for obj, coroutine in zip(objects, pool):
             result = coroutine.next()
-            Ping.objects.create(content_object=obj, **result)
+            Ping.objects.create(content_object=obj, samples=PING_COUNT, date=now, **result)
             coroutine.close()
     return len(objects)
 
 
 @transaction.commit_on_success
 def downsample(model):
-    def aggregate(aggregated, slot_kwargs, minutes):
-        THREEPLACES=decimal.Decimal('0.001')
-        num_pings = len(aggregated)
+    def aggregate(ping_set):
+        THREEPLACES = decimal.Decimal('0.001')
+        set_size = len(ping_set)
+        aggregated = 0
         num_data = 0
-        if num_pings > 1:
-            min = avg = max = mdev = decimal.Decimal(0)
+        if set_size > 1:
+            minimum = 0
+            maximum = 0
+            avg = decimal.Decimal(0)
+            mdev = decimal.Decimal(0)
             packet_loss = 0
-            for ping in aggregated:
+            samples = 0
+            for ping in ping_set:
+                ping_min = sys.maxint if ping.min is None else ping.min
+                minimum = min(minimum, ping_min) or ping.min
+                maximum = max(maximum, ping.max) or ping.max
                 packet_loss += ping.packet_loss
-                if ping.min:
-                    min += ping.min
-                    avg += ping.avg
-                    max += ping.max
-                    mdev += ping.mdev
-                    num_data += 1
+                samples += ping.samples
+                if ping.avg:
+                    avg += ping.avg*ping.samples
+                    # http://en.wikipedia.org/wiki/Standard_deviation#Sample-based_statistics
+                    mdev += (ping.samples-1)*(ping.mdev**2) + ping.samples*(ping.avg**2)
+                    num_data += ping.samples
                 ping.delete()
-            kwargs = dict(slot_kwargs)
-            # FIXME get the mean time instead
-            kwargs['minute'] -= (minutes/2)
-            ping = Ping(
-                packet_loss=(packet_loss/num_pings),
-                date=datetime(tzinfo=timezone.utc, **kwargs),
-                content_object=ping.content_object)
+                aggregated += 1
+            packet_loss = packet_loss/set_size
+            ping = Ping(samples=samples, packet_loss=packet_loss, date=ping.date,
+                    content_object=ping.content_object)
             if num_data:
-                ping.min = (min/num_data).quantize(THREEPLACES)
-                ping.avg = (avg/num_data).quantize(THREEPLACES)
-                ping.max = (max/num_data).quantize(THREEPLACES)
-                # FIXME http://stats.stackexchange.com/questions/25848/how-to-sum-a-standard-deviation
-                ping.mdev = (mdev/num_data).quantize(THREEPLACES)
+                avg = avg/num_data
+                mdev = math.sqrt((mdev-(num_data*(avg**2))) / (num_data-1))
+                ping.min = minimum.quantize(THREEPLACES)
+                ping.max = maximum.quantize(THREEPLACES)
+                ping.avg = avg.quantize(THREEPLACES)
+                ping.mdev = round(mdev, 3)
             ping.save()
-    
-    def get_hourly_slot(ping, minutes):
-        return {
-            'year': ping.date.year,
-            'month': ping.date.month,
-            'day': ping.date.day,
-            'hour': ping.date.hour,
-            'minute': minutes-1,
-            'second': datetime.max.second,
-            'microsecond': datetime.max.microsecond
-        }
+        return aggregated, set_size
     
     model = get_model(*model.split('.'))
     settings = Ping.get_instance_settings(model)
     downsamples = settings.get('downsamples')
+    result = {
+        'aggregated': 0,
+        'created': 0,
+        'total': 0,
+    }
     now = timezone.now()
     for obj in model.objects.all():
-        end = None
+        ini = None
         for downsample in downsamples:
-            delta, minutes = downsample
-            ini = now-delta
-            pings = obj.pings.order_by('date').filter(date__lte=ini.strftime('%Y-%m-%d'))
-            if end:
-                pings = pings.filter(date__gt=end.strftime('%Y-%m-%d'))
-            slot_kwargs = get_hourly_slot(pings[0], minutes)
-            aggregated = []
-            for ping in pings:
-                slot_date = datetime(tzinfo=timezone.utc, **slot_kwargs)
-                if ping.date <= slot_date:
-                    aggregated.append(ping)
-                else:
-                    aggregate(aggregated, slot_kwargs, minutes)
-                    aggregated = []
-                    slot_kwargs['minute'] += minutes
-                    if slot_kwargs['minute'] > 59:
-                        slot_kwargs = get_hourly_slot(ping, minutes)
-            aggregate(aggregated, slot_kwargs, minutes)
-            end = ini
+            period, delta = downsample
+            end = get_sloted_start(now-period, period)
+            pings = obj.pings.order_by('date').filter(date__lte=end)
+            if ini:
+                pings = pings.filter(date__gt=ini)
+            if pings:
+                for __, ping_set in group_by_interval(pings, delta):
+                    aggregated, set_size = aggregate(ping_set)
+                    result['aggregated'] += aggregated
+                    result['total'] += set_size
+                    result['created'] += 1 if aggregated else 0
+            ini = end
+    return "(%(aggregated)s -> %(created)s) / %(total)s" % result
 
 
 for instance in PING_INSTANCES:
@@ -170,8 +169,8 @@ for instance in PING_INSTANCES:
         def ping_instance(model=instance.get('model')):
             return ping(model)
         
-#        name = "pings.%s_aggregate" % instance.get('app')
-#        @periodic_task(name=name, run_every=crontab(minute=0, hour=hour))
-#        def aggregate_pings(model=instance.get('model')):
-#            return downsample(model)
+        name = "pings.%s_downsample" % instance.get('app')
+        @periodic_task(name=name, run_every=crontab(minute=0, hour=hour), time_limit=60*60*2)
+        def downsample_pings(model=instance.get('model')):
+            return downsample(model)
         hour += 1
