@@ -7,7 +7,6 @@ def wrap_action(action, modeladmin):
         queryset = modeladmin.model.objects.filter(pk=object_id)
         response = action(modeladmin, request, queryset)
         if not response:
-            opts = modeladmin.model._meta
             return HttpResponseRedirect(reverse('admin:slices_slice_slivers', 
                 kwargs={'slice_id': slice_id, 'object_id': object_id}))
         return response
@@ -20,3 +19,12 @@ def remove_slice_id(view):
         return view(*args, **kwargs)
     return wrapper
 
+
+def save_files_with_pk_value(obj, fields, *args, **kwargs):
+    for field in fields:
+        if getattr(obj, field):
+            # Dirty hack in order to allow pk values on exp_data filename
+            field_value = getattr(obj, field)
+            setattr(obj, field, None)
+            super(type(obj), obj).save(*args, **kwargs)
+            setattr(obj, field, field_value)
