@@ -3,7 +3,7 @@ from IPy import IP
 
 from controller.settings import DEBUG_IPV6_PREFIX
 from controller.utils.ip import int_to_hex_str, split_len
-
+from nodes.models import Node
 
 from .models import Sliver
 
@@ -34,6 +34,9 @@ class BaseIface(object):
     
     def ipv4_addr(self, iface):
         return None
+    
+    def is_allowed(self, slice, queryset):
+        return True
 
 
 class IsolatedIface(BaseIface):
@@ -48,10 +51,13 @@ class IsolatedIface(BaseIface):
     ALLOW_BULK = False
     
     def clean_model(self, iface):
-        if not iface.slice.vlan_nr:
+        if not iface.sliver.slice.vlan_nr:
             raise ValidationError("Slice vlan_nr is mandatory for isolated interfaces.")
         if not iface.parent:
             raise ValidationError("Parent is mandatory for isolated interfaces.")
+    
+    def is_allowed(self, slice, queryset):
+        return bool(slice.vlan_nr)
 
 
 class Pub4Iface(BaseIface):
@@ -64,9 +70,8 @@ class Pub4Iface(BaseIface):
     
     def clean_model(self, iface):
         super(Pub4Iface, self).clean_model(iface)
-        # TODO this breaks because ifce.sliver_id is not available at this time :( ?
-#        if iface.sliver.node.sliver_pub_ipv4 == 'none':
-#            raise ValidationError("public4 is only available if node's sliver_pub_ipv4 is not None")
+        if iface.sliver.node.sliver_pub_ipv4 == 'none':
+            raise ValidationError("public4 is only available if node's sliver_pub_ipv4 is not None")
     
     def ipv4_addr(self, iface):
         return 'Unknown'
@@ -82,6 +87,9 @@ class Pub6Iface(BaseIface):
     
     def ipv6_addr(self, iface):
         return 'Unknown'
+    
+    def is_allowed(self, slice, queryset):
+        return not queryset.filter(sliver_pub_ipv6=Node.NONE).exists()
 
 
 class DebugIface(BaseIface):
