@@ -14,8 +14,8 @@ from permissions.admin import PermissionModelAdmin, PermissionTabularInline
 
 from .actions import join_request, enable_account, send_email
 from .filters import MyGroupsListFilter
-from .forms import (UserCreationForm, UserChangeForm, RolesFormSet, JoinRequestForm,
-    GroupAdminForm, RolesInlineForm)
+from .forms import (UserCreationForm, UserChangeForm, GroupRolesFormSet,
+    UserRolesForm, JoinRequestForm, GroupAdminForm, GroupRolesInlineForm)
 from .models import User, AuthToken, Roles, Group, JoinRequest, ResourceRequest
 
 
@@ -36,18 +36,18 @@ class AuthTokenInline(PermissionTabularInline):
         return super(AuthTokenInline, self).formfield_for_dbfield(db_field, **kwargs)
 
 
-class RolesInline(PermissionTabularInline, SortableTabularInline):
+class GroupRolesInline(PermissionTabularInline, SortableTabularInline):
     model = Roles
     extra = 0
-    formset = RolesFormSet
-    form = RolesInlineForm
+    formset = GroupRolesFormSet
+    form = GroupRolesInlineForm
     sortable_fields = {'user': 'user__username'}
-    verbose_name = "member"
-    verbose_name_plural = "members" 
-
+    verbose_name = 'member'
+    verbose_name_plural = 'members'
+    
     class Media:
         css = { 'all': ('controller/css/hide-inline-id.css',) }
-
+    
     def get_formset(self, request, obj=None, **kwargs):
         """
         Hook obj into formset to tell the difference bewteen add or change so it
@@ -56,20 +56,21 @@ class RolesInline(PermissionTabularInline, SortableTabularInline):
         """
         self.formset.group = obj
         self.form.group = obj
-        return super(RolesInline, self).get_formset(request, obj=obj, **kwargs)
+        return super(GroupRolesInline, self).get_formset(request, obj=obj, **kwargs)
     
     def has_add_permission(self, request):
         """ Disable add roles when adding a new group """
         if resolve(request.path).url_name == 'users_group_add':
             return False
-        return super(RolesInline, self).has_add_permission(request)
+        return super(GroupRolesInline, self).has_add_permission(request)
 
 
-class ReadOnlyRolesInline(PermissionTabularInline):
-    fields = ['group_link', 'is_admin', 'is_technician', 'is_researcher']
-    readonly_fields = ['group_link', 'is_admin', 'is_technician', 'is_researcher']
+class UserRolesInline(PermissionTabularInline):
+    fields = ['group_link', 'group', 'is_admin', 'is_technician', 'is_researcher']
+    readonly_fields = ['group_link', 'group', 'is_admin', 'is_technician', 'is_researcher']
     model = Roles
     extra = 0
+    form = UserRolesForm
     
     def group_link(self, instance):
         """ Link to related Group """
@@ -79,16 +80,29 @@ class ReadOnlyRolesInline(PermissionTabularInline):
     def get_fieldsets(self, request, obj=None):
         """ HACK display message using the field name of the inline form """
         name = 'Roles'
-        groups_url = reverse('admin:users_group_changelist')
-        if request.user.is_superuser:
-            name = 'Roles <a href="%s">(Manage groups)</a>' % groups_url
-        elif self.has_change_permission(request, obj, view=False):
-            name = 'Roles <a href="%s">(Request group membership)</a>' % groups_url
+        if obj is not None:
+            if self.has_change_permission(request, obj, view=False):
+                groups_url = reverse('admin:users_group_changelist')
+                name = 'Roles <a href="%s">(Request group membership)</a>' % groups_url
         self.verbose_name_plural = mark_safe(name)
-        return super(ReadOnlyRolesInline, self).get_fieldsets(request, obj=obj)
+        fieldsets = super(UserRolesInline, self).get_fieldsets(request, obj=obj)
+        fields = list(fieldsets[0][1]['fields'])
+        if request.user.is_superuser:
+            fields.remove('group_link')
+        else:
+            fields.remove('group')
+        fieldsets[0][1]['fields'] = fields
+        return fieldsets
     
-    def has_add_permission(self, *args, **kwargs):
-        return False
+    def get_readonly_fields(self, request, obj=None):
+        """ Makes all fields read only if user doesn't have change permissions """
+        fields = super(UserRolesInline, self).get_readonly_fields(request, obj)
+        if request.user.is_superuser:
+            return ['group_link']
+        return fields
+    
+    def has_add_permission(self, request, **kwargs):
+        return request.user.is_superuser
 
 
 class JoinRequestInline(PermissionTabularInline):
@@ -127,7 +141,10 @@ class UserAdmin(UserAdmin, PermissionModelAdmin):
         ('Personal info', {'fields': ('first_name', 'last_name', 'email',
                                       'description',)}),
         ('Permissions', {'fields': ('is_active', 'is_superuser',)}),
-        ('Important dates', {'fields': ('last_login', 'date_joined')}),
+        ('Important dates', {
+            'classes': ('collapse',),
+            'fields': ('last_login', 'date_joined')
+        }),
     )
     add_fieldsets = (
         (None, {
@@ -136,7 +153,7 @@ class UserAdmin(UserAdmin, PermissionModelAdmin):
         ),)
     
     search_fields = ('username', 'email', 'first_name', 'last_name')
-    inlines = [AuthTokenInline, ReadOnlyRolesInline]
+    inlines = [AuthTokenInline, UserRolesInline]
     actions = [enable_account, send_email]
     sudo_actions = ['delete_selected', 'enable_account', 'send_email']
     filter_horizontal = ()
@@ -161,6 +178,14 @@ class UserAdmin(UserAdmin, PermissionModelAdmin):
         if db_field.name == 'description':
             kwargs['widget'] = forms.Textarea(attrs={'cols': 85, 'rows': 5})
         return super(UserAdmin, self).formfield_for_dbfield(db_field, **kwargs)
+    
+    def get_inline_instances(self, request, obj=None):
+        """ show/hide inlines depending if is a new obj """
+        inlines = super(UserAdmin, self).get_inline_instances(request, obj=obj)
+        if obj is None:
+            # Remove roles inline
+            return inlines[:1]
+        return inlines
 
 
 class GroupAdmin(ChangeViewActions, PermissionModelAdmin):
@@ -169,7 +194,7 @@ class GroupAdmin(ChangeViewActions, PermissionModelAdmin):
     ]
     list_filter = [MyGroupsListFilter, 'allow_slices', 'allow_nodes']
     search_fields = ['name', 'description']
-    inlines = [RolesInline, JoinRequestInline]
+    inlines = [GroupRolesInline, JoinRequestInline]
     actions = [join_request]
     change_view_actions = [join_request]
     change_form_template = 'admin/users/group/change_form.html'
@@ -198,7 +223,8 @@ class GroupAdmin(ChangeViewActions, PermissionModelAdmin):
         elif self.has_change_permission(request, obj, view=False):
             return inlines
         else:
-            return inlines[:1] #remove(JoinRequestInline)
+            # remove JoinRequestInline
+            return inlines[:1] 
 
     def get_readonly_fields(self, request, obj=None):
         """ Make allow_resource readonly accordingly """
@@ -248,6 +274,51 @@ class GroupAdmin(ChangeViewActions, PermissionModelAdmin):
         return qs
 
 
+class RolesAdmin(admin.ModelAdmin):
+    list_display = [
+        'user_query_string', 'group_link', 'is_admin', 'is_technician', 'is_researcher'
+    ]
+    list_editable = ['is_admin', 'is_technician', 'is_researcher']
+    list_filter = ['is_admin', 'is_technician', 'is_researcher', 'group']
+    
+    def group_link(self, instance):
+        """ Link to related Group """
+        return get_admin_link(instance.group)
+    group_link.short_description = 'Group'
+    group_link.admin_order_field = 'group'
+    
+    def user_query_string(self, instance):
+        query_string = '?'+self.__request__.META['QUERY_STRING']
+        url = reverse('admin:users_roles_change', args=[instance.pk])+query_string
+        return mark_safe('<a href="%s">%s</a>' % (url, instance.user))
+    user_query_string.short_description = 'User'
+    user_query_string.admin_order_field = 'user'
+    
+    def changelist_view(self, request, *args, **kwargs):
+        """ hook request for use in user_query_string """
+        self.__request__ = request
+        return super(RolesAdmin, self).changelist_view(request, *args, **kwargs)
+    
+    def _preserve_query_string(self, request, response):
+        query_string = '?' + request.META['QUERY_STRING']
+        location = response._headers['location']
+        response._headers['location'] = (location[0], location[1]+query_string)
+        return response
+    
+    def response_add(self, request, *args, **kwargs):
+        response = super(RolesAdmin, self).response_add(request, *args, **kwargs)
+        return self._preserve_query_string(request, response)
+    
+    def response_change(self, request, obj):
+        response = super(RolesAdmin, self).response_change(request, obj)
+        return self._preserve_query_string(request, response)
+    
+    def response_action(self, request, queryset):
+        response = super(RolesAdmin, self).response_action(request, queryset)
+        return response
+
+
 admin.site.register(User, UserAdmin)
 admin.site.register(Group, GroupAdmin)
+admin.site.register(Roles, RolesAdmin)
 admin.site.unregister(AuthGroup)
