@@ -1,14 +1,13 @@
 from django import forms
-from django.contrib.auth.forms import ReadOnlyPasswordHashField
 from django.contrib.sites.models import RequestSite
 from django.core.exceptions import ValidationError
 from django.template.defaultfilters import mark_safe
 
 from controller.forms.fields import MultiSelectFormField
-from controller.admin.utils import get_admin_link
+from controller.admin.utils import get_admin_link, get_modeladmin
 from controller.forms.widgets import ReadOnlyWidget
 
-from users.models import User, Group, JoinRequest, ResourceRequest
+from .models import User, Group, JoinRequest, ResourceRequest, Roles
 
 
 class UserCreationForm(forms.ModelForm):
@@ -49,11 +48,11 @@ class UserChangeForm(forms.ModelForm):
         return self.initial["password"]
 
 
-class RolesFormSet(forms.models.BaseInlineFormSet):
+class GroupRolesFormSet(forms.models.BaseInlineFormSet):
     """ At least on admin per group """
     # TODO: ensure this also when deleting a user (more triky though)
     def clean(self):
-        super(RolesFormSet, self).clean()
+        super(GroupRolesFormSet, self).clean()
         # Only checking in change forms
         if self.group is not None:
             for form in self.forms:
@@ -62,19 +61,39 @@ class RolesFormSet(forms.models.BaseInlineFormSet):
             raise ValidationError('The group must have at least one admin')
 
 
-class RolesInlineForm(forms.ModelForm):
+class UserRolesForm(forms.ModelForm):
+    """ At least on admin per group """
+    def __init__(self, *args, **kwargs):
+        super(UserRolesForm, self).__init__(*args, **kwargs)
+        if 'group' in self.fields:
+            # readonly forms doesn't have fields
+            instance = kwargs.get('instance', None)
+            if instance:
+                self.fields['group'].widget = ReadOnlyWidget(original_value=instance.group.pk,
+                        display_value=mark_safe('<b>'+get_admin_link(instance.group)))
+    
+    def clean(self):
+        if not self.cleaned_data.get('is_admin'):
+            role = self.instance
+            admins = Roles.objects.filter(group=role.group, is_admin=True).exclude(pk=role.pk)
+            if not admins.exists():
+                raise ValidationError('The group must have at least one admin')
+        return super(UserRolesForm, self).clean()
+
+
+class GroupRolesInlineForm(forms.ModelForm):
     """ Display user as link and limits user queryset to the remaining ones """
     def __init__(self, *args, **kwargs):
-        super(RolesInlineForm, self).__init__(*args, **kwargs)
+        super(GroupRolesInlineForm, self).__init__(*args, **kwargs)
         if 'user' in self.fields:
             # readonly forms doesn't have fields
             instance = kwargs.get('instance', None)
             if instance:
                 self.fields['user'].widget = ReadOnlyWidget(original_value=instance.user.pk,
-                    display_value=mark_safe('<b>'+get_admin_link(instance.user)))
+                        display_value=mark_safe('<b>'+get_admin_link(instance.user)))
             elif self.group:
-                users = User.objects.exclude(roles__group=self.group).distinct().order_by('username')
-                self.fields['user'].queryset = users
+                users = User.objects.exclude(roles__group=self.group).distinct()
+                self.fields['user'].queryset = users.order_by('username')
 
 
 class GroupAdminForm(forms.ModelForm):
@@ -102,8 +121,8 @@ class GroupAdminForm(forms.ModelForm):
                 # show a message to the operators if exists a resource request
                 elif has_request and 'allow_%s' % resource in self.fields:
                     label = mark_safe("%s <span class='help' style='color:black'>"
-                        "(resource requested by the admin of the group)</span>"
-                        % self.fields['allow_%s' % resource].label)
+                            "(resource requested by the admin of the group)</span>"
+                            % self.fields['allow_%s' % resource].label)
                     self.fields['allow_%s' % resource].label = label
     
     def save(self, commit=True):
@@ -141,7 +160,8 @@ class JoinRequestForm(forms.ModelForm):
         ('technician', 'Technician'),
         ('researcher', 'Researcher'))
     
-    action = forms.ChoiceField(label='Action', choices=ACTIONS, required=False, widget=forms.RadioSelect)
+    action = forms.ChoiceField(label='Action', choices=ACTIONS, required=False,
+            widget=forms.RadioSelect)
     roles = MultiSelectFormField(label='Roles', choices=ROLES, required=False)
     
     class Meta:
@@ -157,17 +177,26 @@ class JoinRequestForm(forms.ModelForm):
     def save(self, commit=True):
         action = self.cleaned_data.get('action')
         roles = self.cleaned_data.get('roles')
-        site = RequestSite(self.__request__)
+        request = self.__request__
+        site = RequestSite(request)
+        jrequest = self.instance
+        username = jrequest.user.get_full_name()
+        log = ''
         if roles and action in ['accept', '']:
             # Accept if explicit and also when a role is selected without any action
-            self.instance.accept(roles=roles)
-            self.instance.send_acceptation_email(site=site)
+            jrequest.accept(roles=roles)
+            jrequest.send_acceptation_email(site=site)
+            log = "Accepted join request of user %s with initial roles: %s." % (username, roles)
         elif action == 'reject':
-            self.instance.reject()
-            self.instance.send_rejection_email(site=site)
+            jrequest.reject()
+            jrequest.send_rejection_email(site=site)
+            log = "Rejected join request of user %s." % username
         elif action == 'ignore':
-            self.instance.delete()
-
+            jrequest.delete()
+            log = "Ignored join request of user %s." % username
+        if log:
+            modeladmin = get_modeladmin(Group)
+            modeladmin.log_change(request, jrequest.group, log)
 
 class SendMailForm(forms.Form):
     subject = forms.CharField(widget=forms.TextInput(attrs={'size':'118'}))
