@@ -33,6 +33,21 @@ class Group(models.Model):
     def __unicode__(self):
         return self.name
     
+    def save(self, *args, **kwargs):
+        """ Make sure nodes and slices are disabled if not allowed
+            NOTE: state will be kept if current state is lower
+        """
+        original = Group.objects.get(pk=self.pk) if self.pk else False
+        super(Group, self).save(*args, **kwargs)
+        if not original: return
+        if original.allow_slices and not self.allow_slices:
+            from slices.models import Slice
+            Slice.objects.filter(group=self, \
+                set_state=Slice.START).update(set_state=Slice.DEPLOY)
+        if original.allow_nodes and not self.allow_nodes:
+            from nodes.models import Node
+            Node.objects.filter(group=self, \
+                set_state=Node.PRODUCTION).update(set_state=Node.SAFE)
     @property
     def admins(self):
         """ returns user queryset containing all admins """
@@ -237,6 +252,13 @@ class User(auth_models.AbstractBaseUser):
     
     def is_member(self, group):
         return self.roles.filter(group=group).exists()
+    
+    @classmethod
+    def get_emails(cls, role=False, roles=[]):
+        if role:
+            roles.append(role)
+        users = cls.objects.filter_by_role(roles=roles)
+        return users.values_list('email', flat=True)
 
 
 class AuthToken(models.Model):
