@@ -133,16 +133,17 @@ function install_requirements () {
                      django-celery-email \
                      django-fluent-dashboard \
                      south \
-                     django-private-files \
                      IPy \
                      django-singletons \
                      django-extensions \
                      django_transaction_signals \
                      django-celery \
+                     jsonfield \
                      markdown \
                      django-filter \
                      django-admin-tools \
-                     djangorestframework==2.3.5"
+                     djangorestframework==2.3.8 \
+                     https://github.com/admin947/django-orphaned/archive/master.zip"
     LOCAL_PIP="paramiko \
                pygments \
                requests==1.2.0 \
