@@ -37,7 +37,7 @@ if is_installed('api'):
     
     urlpatterns += patterns('',
         url(r'^api-auth/', include('rest_framework.urls', namespace='rest_framework')),
-        url(r'^api-token-auth/', 'rest_framework.authtoken.views.obtain_auth_token'),
+        url(r'^api-token-auth/', 'rest_framework.authtoken.views.obtain_auth_token', name='api-token-auth'),
         url(r'^api/', include(api.urls)),)
 
 
