@@ -2,6 +2,7 @@ from __future__ import absolute_import
 
 import os
 import time
+import warnings
 from distutils.sysconfig import get_python_lib
 from urlparse import urlparse
 
@@ -35,27 +36,23 @@ def autodiscover(module):
 
 def is_installed(app):
     """ returns True if app is installed """
-    from django.conf import settings
-    return app in settings.INSTALLED_APPS
+    from .apps import is_installed
+    warnings.warn("Deprecated: use controller.utils.apps.add_app", DeprecationWarning)
+    is_installed(app)
 
 
 def add_app(INSTALLED_APPS, app, prepend=False, append=True):
     """ add app to installed_apps """
-    if app not in INSTALLED_APPS:
-        if prepend:
-            return (app,) + INSTALLED_APPS
-        else:
-            return INSTALLED_APPS + (app,)
-    return INSTALLED_APPS
+    from .apps import add_app
+    warnings.warn("Deprecated: use controller.utils.apps.add_app", DeprecationWarning)
+    return add_app(INSTALLED_APPS, app)
 
 
 def remove_app(INSTALLED_APPS, app):
     """ remove app from installed_apps """
-    if app in INSTALLED_APPS:
-        apps = list(INSTALLED_APPS)
-        apps.remove(app)
-        return tuple(apps)
-    return INSTALLED_APPS
+    from .apps import remove_app
+    warnings.warn("Deprecated: use controller.utils.apps.remove_app", DeprecationWarning)
+    return remove_app(INSTALLED_APPS, app)
 
 
 def get_controller_site():
@@ -68,7 +65,8 @@ def get_controller_site():
     return {
         'domain': url.netloc,
         'name': controller_settings.SITE_NAME,
-        'scheme': url.scheme}
+        'scheme': url.scheme
+    }
 
 
 def send_email_template(template, context, to, email_from=None, html=None):
@@ -110,20 +108,21 @@ def get_existing_pip_installation():
 
 
 def update_settings(monkey_patch=None, **options):
-    """ Warning this only works with a very simple setting format: NAME = 'value' """
+    """ Warning this only works with a very simple setting format: NAME = value """
     from django.conf import settings
     for name, value in options.iteritems():
         if getattr(settings, name, None) != value:
             settings_file = os.path.join(get_project_root(), 'settings.py')
             context = {
                 'name': name,
-                'value': value,
-                'settings': settings_file,}
-            if run("grep '%(name)s' %(settings)s" % context, err_codes=[0,1]):
+                'value': value if not isinstance(value, basestring) else "'%s'" % value,
+                'settings': settings_file,
+            }
+            if run("grep '^%(name)s *=' %(settings)s" % context, err_codes=[0,1]):
                 # Update existing settings_file
-                run("sed -i \"s#%(name)s = *'.*' *#%(name)s = '%(value)s'#\" %(settings)s" % context)
+                run("sed -i \"s#%(name)s *=.*#%(name)s = %(value)s#\" %(settings)s" % context)
             else:
-                run("echo \"%(name)s = '%(value)s'\" >> %(settings)s" % context)
+                run("echo \"%(name)s = %(value)s\" >> %(settings)s" % context)
             # Monkeypatch controller settings to make available the change globally
             if monkey_patch is not None:
                 module = import_module(monkey_patch)
